@@ -16,6 +16,7 @@ def condense_segments(
     start_dt_col: str,
     end_dt_col: str,
     tolerance: int = 1,
+    retain_shape: bool = True,
 ) -> DataFrame:
     """
     Combines overlapping start and end dates according to the allowable tolerance for
@@ -27,9 +28,14 @@ def condense_segments(
         start_dt_col: Name of the start date column from df.
         end_dt_col: Name of the end date column from df.
         tolerance: The allowable number of days between segments.
+        retain_shape: Retain original column and row counts.
+            Default: True
+            False will return distinct `group_col`, `start_dt_col`, `end_dt_col`.
 
     Returns:
-        Input DataFrame with updated user-supplied start_dt_col, end_dt_col
+        Input Dataframe with two additional date cols
+                                or
+        DataFrame with distinct updated user-supplied start_dt_col, end_dt_col
     """
 
     # Treat group_col as list in all cases
@@ -50,7 +56,7 @@ def condense_segments(
         [F.col(x) for x in (group_col + ["_group_id"])]
     )
 
-    return (
+    condensed_segments_sdf = (
         df.withColumn(
             "_group_id",
             F.when(
@@ -69,12 +75,20 @@ def condense_segments(
         )
         .withColumn("_new_start", F.min(F.col(start_dt_col)).over(win_spec_condense))
         .withColumn("_new_end", F.max(F.col(end_dt_col)).over(win_spec_condense))
-        .drop(start_dt_col, end_dt_col, "_group_id")
-        .withColumnRenamed("_new_start", start_dt_col)
-        .withColumnRenamed("_new_end", end_dt_col)
+        .drop("_group_id")
+        .withColumnRenamed("_new_start", f"condense_{start_dt_col}")
+        .withColumnRenamed("_new_end", f"condense_{end_dt_col}")
         .orderBy([x for x in (group_col + [start_dt_col] + [end_dt_col])])
     )
 
+    if retain_shape:
+        return condensed_segments_sdf
+    else:
+        dis_condensed_sdf = condensed_segments_sdf.select(
+            *group_col, start_dt_col, end_dt_col
+        ).distinct()
+        return dis_condensed_sdf
+
 
 def extend_segments(
     df: DataFrame,
@@ -143,7 +157,7 @@ def extend_segments(
         .agg(
             F.array_sort(F.collect_list(F.array(start_dt_col, end_dt_col))).alias(
                 "_input_segments_array"
-            ),
+            )
         )
         .withColumn(
             "_new_segments",
@@ -317,10 +331,7 @@ def covered_days(
 
 
 def first_event_in_x_days(
-    df: DataFrame,
-    group_col: Union[str, List[str]],
-    start_dt_col: str,
-    days: int,
+    df: DataFrame, group_col: Union[str, List[str]], start_dt_col: str, days: int
 ) -> DataFrame:
     """
     Identify the first valid event in an x-day period. Identify invalid events that are
@@ -463,9 +474,7 @@ def count_events_by_period(
 
 
 def age(
-    dob_col: str,
-    age_dt: Union[str, date, Column],
-    floor_sw: bool = True,
+    dob_col: str, age_dt: Union[str, date, Column], floor_sw: bool = True
 ) -> Column:
     """
     Calculate age.
